summaryrefslogtreecommitdiffstats
path: root/languages/ruby/app_templates/kapp/app.rb
diff options
context:
space:
mode:
Diffstat (limited to 'languages/ruby/app_templates/kapp/app.rb')
-rw-r--r--languages/ruby/app_templates/kapp/app.rb36
1 files changed, 18 insertions, 18 deletions
diff --git a/languages/ruby/app_templates/kapp/app.rb b/languages/ruby/app_templates/kapp/app.rb
index 61531be2..f5b9927e 100644
--- a/languages/ruby/app_templates/kapp/app.rb
+++ b/languages/ruby/app_templates/kapp/app.rb
@@ -9,14 +9,14 @@
class %{APPNAMESC} < KDE::MainWindow
- Q_SLOTS 'fileNew()',
+ slots 'fileNew()',
'fileOpen()',
'fileSave()',
'fileSaveAs()',
'filePrint()',
'optionsPreferences()',
- 'changeStatusbar(const QString&)',
- 'changeCaption(const QString&)'
+ 'changeStatusbar(const TQString&)',
+ 'changeCaption(const TQString&)'
def initialize()
super( nil, "%{APPNAMESC}" )
@@ -41,10 +41,10 @@ class %{APPNAMESC} < KDE::MainWindow
setupGUI();
# allow the view to change the statusbar and caption
- connect(@view, SIGNAL('signalChangeStatusbar(const QString&)'),
- self, SLOT('changeStatusbar(const QString&)'))
- connect(@view, SIGNAL('signalChangeCaption(const QString&)'),
- self, SLOT('changeCaption(const QString&)'))
+ connect(@view, TQ_SIGNAL('signalChangeStatusbar(const TQString&)'),
+ self, TQ_SLOT('changeStatusbar(const TQString&)'))
+ connect(@view, TQ_SIGNAL('signalChangeCaption(const TQString&)'),
+ self, TQ_SLOT('changeCaption(const TQString&)'))
end
@@ -74,19 +74,19 @@ class %{APPNAMESC} < KDE::MainWindow
end
def setupActions()
- KDE::StdAction.openNew(self, SLOT('fileNew()'), actionCollection())
- KDE::StdAction.open(self, SLOT('fileOpen()'), actionCollection())
- KDE::StdAction.save(self, SLOT('fileSave()'), actionCollection())
- KDE::StdAction.saveAs(self, SLOT('fileSaveAs()'), actionCollection())
- KDE::StdAction.print(self, SLOT('filePrint()'), actionCollection())
- KDE::StdAction.quit($kapp, SLOT('quit()'), actionCollection())
+ KDE::StdAction.openNew(self, TQ_SLOT('fileNew()'), actionCollection())
+ KDE::StdAction.open(self, TQ_SLOT('fileOpen()'), actionCollection())
+ KDE::StdAction.save(self, TQ_SLOT('fileSave()'), actionCollection())
+ KDE::StdAction.saveAs(self, TQ_SLOT('fileSaveAs()'), actionCollection())
+ KDE::StdAction.print(self, TQ_SLOT('filePrint()'), actionCollection())
+ KDE::StdAction.quit($kapp, TQ_SLOT('quit()'), actionCollection())
- KDE::StdAction.preferences(self, SLOT('optionsPreferences()'), actionCollection())
+ KDE::StdAction.preferences(self, TQ_SLOT('optionsPreferences()'), actionCollection())
# this doesn't do anything useful. it's just here to illustrate
# how to insert a custom menu and menu item
custom = KDE::Action.new(i18n("Cus&tom Menuitem"), KDE::Shortcut.new(),
- self, SLOT('optionsPreferences()'),
+ self, TQ_SLOT('optionsPreferences()'),
actionCollection(), "custom_action")
end
@@ -181,13 +181,13 @@ class %{APPNAMESC} < KDE::MainWindow
if @printer.nil? then @printer = KDE::Printer.new end
if @printer.setup(self)
# setup the printer. with Qt, you always "print" to a
# Qt::Painter.. whether the output medium is a pixmap, a screen,
# or paper
- p = Qt::Painter.new
+ p = TQt::Painter.new
p.begin(@printer)
# we let our view do the actual printing
- metrics = Qt::PaintDeviceMetrics.new(@printer)
+ metrics = TQt::PaintDeviceMetrics.new(@printer)
@view.print(p, metrics.height(), metrics.width())
# and send the result to the printer
@@ -181,13 +181,13 @@ class %{APPNAMESC} < KDE::MainWindow
if @printer.setup(self)
# setup the printer. with Qt, you always "print" to a
- # Qt::Painter.. whether the output medium is a pixmap, a screen,
+ # TQt::Painter.. whether the output medium is a pixmap, a screen,
# or paper